==> defi-services-lib-1.0.4.tar.gz: defi-services-lib-1.0.4/src/defi_services/lending_pools/lending_pools_info/ethereum/compound_eth.py <==
COMPOUND_ETH = {
    "chainId": "0x38",
    "name": "Compound Lending Pool",
    "rewardToken": "0xc00e94cb662c3520282e6f5717214004a7f26888",
    "comptrollerAddress": "0x3d9819210a31b4961b30ef54be2aed79b9c9cd3b",
    "lensAddress": "0xA6c8D1c55951e8AC44a0EaA959Be5Fd21cc07531",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x0d8775f648430679a709e98d2b0cb6250d2887ef": {
            "cToken": "0x6c8c6b02e7b2be14d4fa6022dfd6d75921d90e4e",
            "liquidationThreshold": 0.6
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "cToken": "0x5d3a536e4d6dbd6114cc1ead35777bab948e3643",
            "liquidationThreshold": 0.835
        },
        "0x0000000000000000000000000000000000000000": {
            "cToken": "0x4ddc2d193948926d02f9b1fe9e1daa0718270ed5",
            "liquidationThreshold": 0.825
        },
        "0x1985365e9f78359a9b6ad760e32412f4a445e862": {
            "cToken": "0x158079ee67fce2f58472a96584a73c7ab9ac95c1",
            "liquidationThreshold": 0.0
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "cToken": "0x39aa39c021dfbae8fac545936693ac917d5e7563",
            "liquidationThreshold": 0.855
        },
        "0xdac17f958d2ee523a2206206994597c13d831ec7": {
            "cToken": "0xf650c3d88d12db855b8bf7d11be6c55a4e07dcc9",
            "liquidationThreshold": 0.0
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "cToken": "0xccf4429db6322d5c611ee964527d42e5d685dd6a",
            "liquidationThreshold": 0.7
        },
        "0xe41d2489571d322189246dafa5ebde1f4699f498": {
            "cToken": "0xb3319f5d18bc0d84dd1b4825dcde5d5f7266d407",
            "liquidationThreshold": 0.65
        },
        "0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359": {
            "cToken": "0xf5dce57282a584d2746faf1593d3121fcac444dc",
            "liquidationThreshold": 0.0
        },
        "0x1f9840a85d5af5bf1d1762f925bdaddc4201f984": {
            "cToken": "0x35a18000230da775cac24873d00ff85bccded550",
            "liquidationThreshold": 0.75
        },
        "0xc00e94cb662c3520282e6f5717214004a7f26888": {
            "cToken": "0x70e36f6bf80a52b3b46b3af8e106cc0ed743e8e4",
            "liquidationThreshold": 0.6
        },
        "0x0000000000085d4780b73119b644ae5ecd22b376": {
            "cToken": "0x12392f67bdf24fae0af363c24ac620a2f67dad86",
            "liquidationThreshold": 0.0
        },
        "0x514910771af9ca656af840dff83e8264ecf986ca": {
            "cToken": "0xface851a4921ce59e912d19329929ce6da6eb0c7",
            "liquidationThreshold": 0.79
        },
        "0x9f8f72aa9304c8b593d555f12ef6589cc3a579a2": {
            "cToken": "0x95b4ef2869ebd94beb4eee400a99824bf5dc325b",
            "liquidationThreshold": 0.73
        },
        "0x6b3595068778dd592e39a122f4f5a5cf09c90fe2": {
            "cToken": "0x4b0181102a0112a2ef11abee5563bb4a3176c9d7",
            "liquidationThreshold": 0.67
        },
        "0x7fc66500c84a76ad7e9c93437bfc5ac33e2ddae9": {
            "cToken": "0xe65cdb6479bac1e22340e4e755fae7e509ecd06c",
            "liquidationThreshold": 0.73
        },
        "0x0bc529c00c6401aef6d220be8c6ea1667f6ad93e": {
            "cToken": "0x80a2ae356fc9ef4305676f7a3e2ed04e12c33946",
            "liquidationThreshold": 0.75
        },
        "0x8e870d67f660d95d5be530380d0ec0bd388289e1": {
            "cToken": "0x041171993284df560249b57358f931d9eb7b925d",
            "liquidationThreshold": 0.0
        },
        "0x956f47f50a910163d8bf957cf5846d573e7f87ca": {
            "cToken": "0x7713dd9ca933848f6819f38b8352d9a15ea73f67",
            "liquidationThreshold": 0.0
        }
    }
}

==> defi-services-lib-1.0.5.tar.gz: defi-services-lib-1.0.5/src/defi_services/lending_pools/lending_pools_info/ethereum/compound_eth.py <==
COMPOUND_ETH = {
    "chainId": "0x38",
    "name": "Compound Lending Pool",
    "rewardToken": "0xc00e94cb662c3520282e6f5717214004a7f26888",
    "comptrollerAddress": "0x3d9819210a31b4961b30ef54be2aed79b9c9cd3b",
    "lensAddress": "0xa6c8d1c55951e8ac44a0eaa959be5fd21cc07531",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x0d8775f648430679a709e98d2b0cb6250d2887ef": {
            "cToken": "0x6c8c6b02e7b2be14d4fa6022dfd6d75921d90e4e",
            "liquidationThreshold": 0.6
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "cToken": "0x5d3a536e4d6dbd6114cc1ead35777bab948e3643",
            "liquidationThreshold": 0.835
        },
        "0x0000000000000000000000000000000000000000": {
            "cToken": "0x4ddc2d193948926d02f9b1fe9e1daa0718270ed5",
            "liquidationThreshold": 0.825
        },
        "0x1985365e9f78359a9b6ad760e32412f4a445e862": {
            "cToken": "0x158079ee67fce2f58472a96584a73c7ab9ac95c1",
            "liquidationThreshold": 0.0
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "cToken": "0x39aa39c021dfbae8fac545936693ac917d5e7563",
            "liquidationThreshold": 0.855
        },
        "0xdac17f958d2ee523a2206206994597c13d831ec7": {
            "cToken": "0xf650c3d88d12db855b8bf7d11be6c55a4e07dcc9",
            "liquidationThreshold": 0.0
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "cToken": "0xccf4429db6322d5c611ee964527d42e5d685dd6a",
            "liquidationThreshold": 0.7
        },
        "0xe41d2489571d322189246dafa5ebde1f4699f498": {
            "cToken": "0xb3319f5d18bc0d84dd1b4825dcde5d5f7266d407",
            "liquidationThreshold": 0.65
        },
        "0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359": {
            "cToken": "0xf5dce57282a584d2746faf1593d3121fcac444dc",
            "liquidationThreshold": 0.0
        },
        "0x1f9840a85d5af5bf1d1762f925bdaddc4201f984": {
            "cToken": "0x35a18000230da775cac24873d00ff85bccded550",
            "liquidationThreshold": 0.75
        },
        "0xc00e94cb662c3520282e6f5717214004a7f26888": {
            "cToken": "0x70e36f6bf80a52b3b46b3af8e106cc0ed743e8e4",
            "liquidationThreshold": 0.6
        },
        "0x0000000000085d4780b73119b644ae5ecd22b376": {
            "cToken": "0x12392f67bdf24fae0af363c24ac620a2f67dad86",
            "liquidationThreshold": 0.0
        },
        "0x514910771af9ca656af840dff83e8264ecf986ca": {
            "cToken": "0xface851a4921ce59e912d19329929ce6da6eb0c7",
            "liquidationThreshold": 0.79
        },
        "0x9f8f72aa9304c8b593d555f12ef6589cc3a579a2": {
            "cToken": "0x95b4ef2869ebd94beb4eee400a99824bf5dc325b",
            "liquidationThreshold": 0.73
        },
        "0x6b3595068778dd592e39a122f4f5a5cf09c90fe2": {
            "cToken": "0x4b0181102a0112a2ef11abee5563bb4a3176c9d7",
            "liquidationThreshold": 0.67
        },
        "0x7fc66500c84a76ad7e9c93437bfc5ac33e2ddae9": {
            "cToken": "0xe65cdb6479bac1e22340e4e755fae7e509ecd06c",
            "liquidationThreshold": 0.73
        },
        "0x0bc529c00c6401aef6d220be8c6ea1667f6ad93e": {
            "cToken": "0x80a2ae356fc9ef4305676f7a3e2ed04e12c33946",
            "liquidationThreshold": 0.75
        },
        "0x8e870d67f660d95d5be530380d0ec0bd388289e1": {
            "cToken": "0x041171993284df560249b57358f931d9eb7b925d",
            "liquidationThreshold": 0.0
        },
        "0x956f47f50a910163d8bf957cf5846d573e7f87ca": {
            "cToken": "0x7713dd9ca933848f6819f38b8352d9a15ea73f67",
            "liquidationThreshold": 0.0
        }
    }
}
